<?php

if (!defined('_PS_VERSION_'))
	exit;

class BlockCmsFooterOut extends Module
{
	public function __construct()
	{
		$this->name = 'blockcmsfooterout';
		$this->tab = 'front_office_features';
		$this->version = '1.0.0';
		$this->author = 'Webproggi.ru';
		$this->need_instance = 0;

		$this->bootstrap = true;
		parent::__construct();

		$this->displayName = $this->l('Block CMS Footer Out');
		$this->description = $this->l('Displays a CMS block in the footer for CMS pages.');
	}

	public function install()
	{
		return
			parent::install() &&
			$this->registerHook('displayFooter') &&
			$this->registerHook('displayHeader') && 
			Configuration::updateValue('BLOCKCMSOUT_CMS_F', 1);
	}

	public function uninstall()
	{
		Configuration::deleteByName('BLOCKCMSOUT_CMS_F');
		return parent::uninstall();
	}

	public function hookDisplayFooter($params)
	{
		if (!$this->isCached('blockcmsfooterout.tpl', $this->getCacheId()))
		{
			$context = Context::getContext();
			$id_lang = (int)$this->context->language->id;
			$id_shop = (int)$this->context->shop->id;
			
			$sql = new DbQuery();
        	$sql->select('*');
        	$sql->from('cms', 'c');

            $sql->innerJoin('cms_lang', 'l', 'c.id_cms = l.id_cms AND l.id_lang = '.(int)$id_lang.' AND l.id_shop = '.(int)$id_shop);

            $sql->innerJoin('cms_shop', 'cs', 'c.id_cms = cs.id_cms AND cs.id_shop = '.(int)$id_shop);
	        $sql->where('c.active = 1');
	        $sql->where('c.id_cms in ('.trim(Configuration::get('BLOCKCMSOUT_CMS_F')).')');

        	$sql->orderBy('position');

        	$arr_cat = Db::getInstance()->executeS($sql);


			if (count($arr_cat) > 0){
				foreach ($arr_cat as $value => $cat)
				{
					$arr_cat[$value]['link'] = $context->link->getCMSLink((int)$cat['id_cms'], $cat['link_rewrite']);
				}
			}

			$this->smarty->assign(array(
				'cms_out_footer_arr' => $arr_cat
			));
		}

		return $this->display(__FILE__, 'blockcmsfooterout.tpl', $this->getCacheId());
	}

	public function hookDisplayHeader($params)
	{
		$this->context->controller->addCSS($this->_path.'blockcmsfooterout.css', 'all');
	}

	public function postProcess()
	{
		if (Tools::isSubmit('submitConf'))
		{
			Configuration::updateValue('BLOCKCMSOUT_CMS_F', Tools::getValue('blockcmsfooterout_cms'));

			$this->_clearCache('blockcmsfooterout.tpl');
			return $this->displayConfirmation($this->l('The settings have been updated.'));
		}
		return '';
	}

	public function getContent()
	{
		return $this->postProcess().$this->renderForm();
	}

	public function renderForm()
	{
		$fields_form = array(
			'form' => array(
				'legend' => array(
					'title' => $this->l('Settings'),
					'icon' => 'icon-cogs'
				),
				'input' => array(
					array(
						'type' => 'text',
						'lang' => false,
						'label' => $this->l('CMS pages to show in this module'),
						'name' => 'blockcmsfooterout_cms',
						'desc' => $this->l('Write ID CMS pages, which will be shown in this block in the footer, through a comma.')
					)
				),
				'submit' => array(
					'title' => $this->l('Save')
				)
			),
		);

		$helper = new HelperForm();
		$helper->show_toolbar = false;
		$helper->table = $this->table;
		$lang = new Language((int)Configuration::get('PS_LANG_DEFAULT'));
		$helper->default_form_language = $lang->id;
		$helper->module = $this;

		$helper->identifier = $this->identifier;
		$helper->submit_action = 'submitConf';
		$helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false).'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
		$helper->token = Tools::getAdminTokenLite('AdminModules');
		$helper->tpl_vars = array(
			'uri' => $this->getPathUri(),
			'fields_value' => $this->getConfigFieldsValues(),
			'languages' => $this->context->controller->getLanguages(),
			'id_language' => $this->context->language->id
		);

		return $helper->generateForm(array($fields_form));
	}

	public function getConfigFieldsValues()
	{
		$fields = array();

		$fields['blockcmsfooterout_cms'] = Configuration::get('BLOCKCMSOUT_CMS_F');

		return $fields;
	}
}
